@@ -1,6 +1,6 @@
 "predict.gstat" <-
 function (object, newdata, block = numeric(0), nsim = 0, indicators = FALSE,
-	BLUE = FALSE, debug.level = 1, mask, ...) 
+	BLUE = FALSE, debug.level = 1, mask, na.action = na.pass, ...) 
 {
 	if (missing(object) || length(object$data) < 1) 
 		stop("no data available")
@@ -8,14 +8,14 @@ function (object, newdata, block = numeric(0), nsim = 0, indicators = FALSE,
 		stop("first argument should be of class gstat")
 	.Call("gstat_init", as.integer(debug.level), PACKAGE = "gstat")
 	if (!missing(mask)) {
-		mask = as.logical(mask) & !is.na(mask)
-		nrow.original = nrow(newdata)
-		newdata = newdata[mask, ]
+		# mask = as.logical(mask) & !is.na(mask)
+		# nrow.original = nrow(newdata)
+		# newdata = newdata[mask, ]
+		cat("argument mask is deprecated:")
+		cat("use a missing value pattern in newdata instead")
 	}
 	nvars = length(object$data)
-	pos = 1
 	new.X = NULL
-	names.vars = character(nvars * 2 + nvars * (nvars - 1)/2)
 	for (i in 1:length(object$data)) {
 		name = names(object$data)[i]
 		d = object$data[[i]]
@@ -51,23 +51,17 @@ function (object, newdata, block = numeric(0), nsim = 0, indicators = FALSE,
 		}
 		if (!is.null(object$model[[name]])) 
 			load.variogram.model(object$model[[name]], c(i - 1, i - 1))
-		raw = gstat.formula.predict(d$formula, d$locations, newdata)
+		raw = gstat.formula.predict(d$formula, d$locations, newdata, 
+				na.action = na.action)
 		if (is.null(new.X)) 
 			new.X = raw$X
 		else new.X = cbind(new.X, raw$X)
-		names.vars[1 + (i - 1) * 2] = paste(names(object$data)[i], 
-			"pred", sep = ".")
-		names.vars[2 + (i - 1) * 2] = paste(names(object$data)[i], 
-			"var", sep = ".")
 		if (i > 1) {
 			for (j in 1:(i - 1)) {
-				cross = paste(names(object$data)[j], name, sep = ".")
+				cross = cross.name(names(object$data)[j], name)
 				if (!is.null(object$model[[cross]])) 
 					load.variogram.model(object$model[[cross]], 
 						c(i - 1, j - 1))
-				names.vars[nvars * 2 + pos] = paste("cov", cross, 
-					sep = ".")
-				pos = pos + 1
 			}
 		}
 	}
@@ -80,22 +74,32 @@ function (object, newdata, block = numeric(0), nsim = 0, indicators = FALSE,
 		block = as.numeric(block) # make sure it's not integer
 		block.cols = numeric(0)
 	} 
+	# handle NA's in the parts of newdata used:
+	valid.pattern = NULL
+	if (any(is.na(raw$locations)) || any(is.na(new.X))) {
+		valid.pattern = !(apply(cbind(raw$locations, new.X), 1, 
+				function(x) any(is.na(x))))
+		raw$locations.all = raw$locations
+		raw$locations = as.matrix(raw$locations[valid.pattern, ])
+		new.X = as.matrix(new.X[valid.pattern, ])
+	} 
 	if (nsim) {
 		if (indicators == TRUE)
 			nsim = -abs(nsim)
 	# random path: randomly permute row indices
 		perm = sample(seq(along = new.X[, 1]))
-		ret = .Call("gstat_predict", as.integer(nrow(new.X)), 
+		ret = .Call("gstat_predict", as.integer(nrow(as.matrix(new.X))),
 			as.vector(raw$locations[perm, ]), as.vector(new.X[perm,]), 
 		as.integer(block.cols), as.vector(block), 
 		as.integer(nsim), as.integer(BLUE)
 		, PACKAGE = "gstat"
 		)[[1]]
 		ret = data.frame(cbind(raw$locations, 
-		matrix(ret[order(perm),], nrow(new.X), max(2, abs(nsim) * nvars))))
+		matrix(ret[order(perm),], nrow(as.matrix(new.X)), 
+		max(2, abs(nsim) * nvars))))
 	}
 	else {
-		ret = .Call("gstat_predict", as.integer(nrow(new.X)), 
+		ret = .Call("gstat_predict", as.integer(nrow(as.matrix(new.X))),
 			as.vector(raw$locations), as.vector(new.X), as.integer(block.cols), 
 			as.vector(block), as.integer(nsim), as.integer(BLUE)
 			, PACKAGE = "gstat"
@@ -103,9 +107,10 @@ function (object, newdata, block = numeric(0), nsim = 0, indicators = FALSE,
 		ret = data.frame(cbind(raw$locations, ret))
 	}
 	.Call("gstat_exit", NULL, PACKAGE = "gstat")
-	if (!missing(mask)) {
-		ret.all = data.frame(matrix(NA, nrow.original, ncol(ret)))
-		ret.all[mask, ] = ret
+	if (!is.null(valid.pattern) && any(valid.pattern)) {
+		ret.all = data.frame(matrix(NA, length(valid.pattern), ncol(ret)))
+		ret.all[, 1:ncol(raw$locations.all)] = raw$locations.all
+		ret.all[valid.pattern, ] = ret
 		ret = ret.all
 	}
 	if (abs(nsim) > 0) {
@@ -116,7 +121,30 @@ function (object, newdata, block = numeric(0), nsim = 0, indicators = FALSE,
 		else names.vars = paste("sim", 1:abs(nsim), sep = "")
 		if (abs(nsim) == 1) 
 			ret = ret[, 1:(ncol(ret) - 1)]
-	}
+	} else
+		names.vars = create.gstat.names(names(object$data))
 	names(ret) = c(dimnames(raw$locations)[[2]], names.vars)
 	return(ret)
 }
+
+# call with: create.gstat.names(names(object$data))
+# creates the names of the output columns in case of (multivariable) prediction
+create.gstat.names <- function(ids, names.sep = ".") {
+	nvars = length(ids)
+	names.vars = character(nvars * 2 + nvars * (nvars - 1)/2)
+	pos = 1
+	for (i in 1:length(ids)) {
+		name = ids[i]
+		names.vars[1 + (i - 1) * 2] = paste(name, "pred", sep = names.sep)
+		names.vars[2 + (i - 1) * 2] = paste(name, "var", sep = names.sep)
+		if (i > 1) {
+			for (j in 1:(i - 1)) {
+				cross = paste(ids[j], name, sep = names.sep)
+				names.vars[nvars * 2 + pos] = paste("cov", cross, 
+					sep = names.sep)
+				pos = pos + 1
+			}
+		}
+	}
+	return(names.vars)
+}
